==> phoenix_widgets-1.6.0.tar.gz: example/lib/phoenix_expandable_content_block_page.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixExpandableContentBlockPage extends StatefulWidget {
  const PhoenixExpandableContentBlockPage({Key? key}) : super(key: key);

  @override
  _PhoenixExpandableContentBlockPageState createState() =>
      _PhoenixExpandableContentBlockPageState();
}

class _PhoenixExpandableContentBlockPageState
    extends State<PhoenixExpandableContentBlockPage> {
  @override
  Widget build(BuildContext context) {
    const String text = "Flutter is Google’s portable UI toolkit for building "
        "beautiful, natively-compiled applications for mobile, web, and desktop"
        " from a single codebase. Visit https://flutter.dev to learn more. "
        "Flutter works with existing code, is used by developers and "
        "organizations around the world, and is free and open source. Flutter "
        "is designed to support mobile apps that run on both Android and iOS, "
        "as well as interactive apps that you want to run on your web pages or "
        "on the desktop. (Note that desktop support is in beta, but a snapshot "
        "of the beta is available on the stable channel.)";
    final List<Url> urls = [
      Url("https://flutter.dev", [154, 173])
    ];

    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('Phoenix Expandable Content Sample'),
        ),
        body: Container(
            margin: const EdgeInsets.all(16),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                PhoenixExpandableContentBlock(
                  text: text,
                  style: Theme.of(context).textTheme.bodyText2!,
                  urls: urls,
                  shortenButtonLabel: "[See less]",
                  expandButtonLabel: "[See more]"
                )
              ],
            )));
  }
}

==> phoenix_widgets-1.12.0.tar.gz: example/lib/phoenix_expandable_content_block_page.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixExpandableContentBlockPage extends StatefulWidget {
  const PhoenixExpandableContentBlockPage({Key? key}) : super(key: key);

  @override
  _PhoenixExpandableContentBlockPageState createState() =>
      _PhoenixExpandableContentBlockPageState();
}

class _PhoenixExpandableContentBlockPageState
    extends State<PhoenixExpandableContentBlockPage> {
  @override
  Widget build(BuildContext context) {
    const String text = "Flutter is Google’s portable UI toolkit for building "
        "beautiful, natively-compiled applications for mobile, web, and desktop"
        " from a single codebase. Visit https://flutter.dev to learn more. "
        "Flutter works with existing code, is used by developers and "
        "organizations around the world, and is free and open source. Flutter "
        "is designed to support mobile apps that run on both Android and iOS, "
        "as well as interactive apps that you want to run on your web pages or "
        "on the desktop. (Note that desktop support is in beta, but a snapshot "
        "of the beta is available on the stable channel.)";
    final List<Url> urls = [
      Url("https://flutter.dev", [154, 173])
    ];

    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('Phoenix Expandable Content Sample'),
        ),
        body: Container(
            margin: const EdgeInsets.all(16),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                PhoenixExpandableContentBlock(
                  text: text,
                  style: Theme.of(context).textTheme.bodyText2!,
                  urls: urls,
                  shortenButtonLabel: "[See less]",
                  expandButtonLabel: "[See more]",
                  textCopiedCallback: _onTextCopied
                )
              ],
            )));
  }

  _onTextCopied() {
    ScaffoldMessenger.of(context)
        .showSnackBar(const SnackBar(content: Text("Text Copied")));
  }
}
